@@ -1,13 +1,13 @@
-# Copyrights 2007-2008 by Mark Overmeer.
+# Copyrights 2007-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 use warnings;
 use strict;
 
 package XML::Compile::WSDL11;
 use vars '$VERSION';
-$VERSION = '2.00_01';
+$VERSION = '2.01';
 
 use base 'XML::Compile::Cache';
 
@@ -16,8 +16,6 @@ use Log::Report 'xml-compile-soap', syntax => 'SHORT';
 use XML::Compile::Util       qw/pack_type unpack_type/;
 use XML::Compile::SOAP::Util qw/:wsdl11 SOAP11ENV/;
 
-#use XML::Compile::SOAP11::Operation   ();
-#use XML::Compile::Transport::SOAPHTTP ();
 use XML::Compile::Operation  ();
 use XML::Compile::Transport  ();
 
@@ -51,13 +49,10 @@ sub init($)
           , XML::Compile::Transport->registered;
 
     $self->declare
-     ( READER       => 'wsdl:definitions'
-     , key_rewrite  => 'PREFIXED'
-     , hook         =>
-        { type =>  'wsdl:tOperation'
-        , after => 'ELEMENT_ORDER'
-        }
-     );
+      ( READER      => 'wsdl:definitions'
+      , key_rewrite => 'PREFIXED(wsdl,soap,http)'
+      , hook        => {type => 'wsdl:tOperation', after => 'ELEMENT_ORDER'}
+      );
 
     $self->addWSDL($wsdl);
     $self;
@@ -173,12 +168,12 @@ sub operation(@)
             , portnames => join("\n    ", '', @portnames);
     }
 
-    # get plugin for operation
+    # get plugin for operation # {
 
     my $address   = first { $_ =~ m/[_}]address$/ } keys %$port
         or error __x"no address provided in service port";
 
-    if($address =~ m/^{/)
+    if($address =~ m/^{/)      # }
     {   my ($ns)  = unpack_type $address;
 
         warning __"Since v2.00 you have to require XML::Compile::SOAP11 explicitly"
